ams.core.service.NumOp
======================

.. currentmodule:: ams.core.service

.. autoclass:: NumOp

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~NumOp.assign_memory
       
       
          ~NumOp.evaluate
       
       
          ~NumOp.get_names
       
       
          ~NumOp.parse
       
       
          ~NumOp.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~NumOp.class_name
      ~NumOp.n
      ~NumOp.shape
      ~NumOp.size
      ~NumOp.v
      ~NumOp.v0
      ~NumOp.v1
   
   